pecos.error\_models.noise\_impl\_old.tq\_noise
==============================================

.. automodule:: pecos.error_models.noise_impl_old.tq_noise







   .. rubric:: Functions

   .. autosummary::

      noise_depolarizing_two_qubit_gates
      noise_two_qubit_gates_depolarizing_with_noiseless
